@@ -22,10 +22,9 @@
 #include "cairo-dock-keyfile-utilities.h"
 #include "cairo-dock-module-manager.h"
 #include "cairo-dock-themes-manager.h"  // cairo_dock_write_keys_to_conf_file
-#include "cairo-dock-module-factory.h"
+#include "cairo-dock-module-instance-manager.h"  // gldi_module_instance_reload
 #include "cairo-dock-gui-factory.h"
 #include "cairo-dock-log.h"
-#include "cairo-dock-X-manager.h"
 #include "cairo-dock-widget-config-group.h"
 
 #define CAIRO_DOCK_ICON_MARGIN 6
@@ -46,8 +45,8 @@ static void _config_group_widget_apply (CDWidget *pCdWidget)
 	
 	// reload the associated managers.
 	const gchar *cManagerName, *cModuleName;
-	CairoDockModule *pModule;
-	CairoDockModuleInstance *pExtraInstance;
+	GldiModule *pModule;
+	GldiModuleInstance *pExtraInstance;
 	GldiManager *pManager;
 	GSList *pExtraWidgetList;
 	GKeyFile* pExtraKeyFile;
@@ -56,16 +55,16 @@ static void _config_group_widget_apply (CDWidget *pCdWidget)
 	for (m = pConfigGroupWidget->pManagers; m != NULL; m = m->next)
 	{
 		cManagerName = m->data;
-		pManager = gldi_get_manager (cManagerName);
+		pManager = gldi_manager_get (cManagerName);
 		g_return_if_fail (pManager != NULL);
-		gldi_reload_manager (pManager, g_cConfFile);
+		gldi_object_reload (GLDI_OBJECT(pManager), TRUE);
 		
 		// reload the extensions too
 		for (e = pManager->pExternalModules; e != NULL && w != NULL; e = e->next)
 		{
 			// get the extension
 			cModuleName = e->data;
-			pModule = cairo_dock_find_module_from_name (cModuleName);
+			pModule = gldi_module_get (cModuleName);
 			if (!pModule)
 				continue;
 			
@@ -88,7 +87,7 @@ static void _config_group_widget_apply (CDWidget *pCdWidget)
 			g_key_file_free (pExtraKeyFile);
 			
 			// reload it
-			cairo_dock_reload_module_instance (pExtraInstance, TRUE);
+			gldi_object_reload (GLDI_OBJECT(pExtraInstance), TRUE);
 		}
 	}
 }
@@ -130,8 +129,8 @@ ConfigGroupWidget *cairo_dock_config_group_widget_new (const gchar *cGroupName,
 	// build the widgets of the extensions
 	GtkWidget *pNoteBook = NULL;
 	GKeyFile* pExtraKeyFile;
-	CairoDockModule *pModule;
-	CairoDockModuleInstance *pExtraInstance;
+	GldiModule *pModule;
+	GldiModuleInstance *pExtraInstance;
 	GSList *pExtraWidgetList;
 	gchar *cOriginalConfFilePath;
 	GldiManager *pManager;
@@ -140,14 +139,14 @@ ConfigGroupWidget *cairo_dock_config_group_widget_new (const gchar *cGroupName,
 	for (m = pManagers; m != NULL; m = m->next)
 	{
 		cManagerName = m->data;
-		pManager = gldi_get_manager (cManagerName);
+		pManager = gldi_manager_get (cManagerName);
 		if (!pManager)
 			continue;
 		
 		for (e = pManager->pExternalModules; e != NULL; e = e->next)
 		{
 			cModuleName = e->data;
-			pModule = cairo_dock_find_module_from_name (cModuleName);
+			pModule = gldi_module_get (cModuleName);
 			if (!pModule)
 				continue;
 			
@@ -199,7 +198,11 @@ ConfigGroupWidget *cairo_dock_config_group_widget_new (const gchar *cGroupName,
 		
 		GtkWidget *pScrolledWindow = gtk_scrolled_window_new (NULL, NULL);  // add scrollbars on the widget before putting it into the notebook.
 		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (pScrolledWindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+		#if GTK_CHECK_VERSION (3, 8, 0)
+		gtk_container_add (GTK_CONTAINER (pScrolledWindow), pWidget);
+		#else
 		gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (pScrolledWindow), pWidget);
+		#endif
 		
 		gtk_notebook_prepend_page (GTK_NOTEBOOK (pNoteBook), pScrolledWindow, (pAlign != NULL ? pAlign : pLabel));
 		pWidget = pNoteBook;
