@@ -18,37 +18,34 @@
 */
 
 #include <math.h>
-#include <string.h>
-#include <stdio.h>
 #include <stdlib.h>
 
 #include <gtk/gtk.h>
-
 #include <cairo.h>
 
-
+#include "texture-blur.h"
 #include "gldi-config.h"
-#include "cairo-dock-animations.h"  // implicit
 #include "cairo-dock-icon-facility.h"
 #include "cairo-dock-backends-manager.h"
-#include "cairo-dock-dock-manager.h"
+#include "cairo-dock-stack-icon-manager.h"
+#include "cairo-dock-separator-manager.h"
 #include "cairo-dock-draw.h"
+#include "cairo-dock-animations.h"  // cairo_dock_calculate_magnitude
 #include "cairo-dock-draw-opengl.h"
 #include "cairo-dock-opengl-path.h"
 #include "cairo-dock-log.h"
 #include "cairo-dock-dock-facility.h"
-#include "cairo-dock-notifications.h"
-//#include "cairo-dock-load.h"
-#include "texture-blur.h"
-#include "cairo-dock-X-manager.h"
+#include "cairo-dock-object.h"
+#include "cairo-dock-dock-manager.h"
+#include "cairo-dock-desktop-manager.h"  // gldi_dock_get_screen_width
 #include "cairo-dock-default-view.h"
 
-extern CairoDockDesktopGeometry g_desktopGeometry;
 extern gboolean g_bUseOpenGL;
+
 static GLuint s_iFlatSeparatorTexture = 0;
 
 
-static gboolean cd_default_view_free_data (gpointer pUserData, CairoDock *pDock)  // si la vue 'default' etait dans un plug-in on n'aurait pas besoin de faire ca (on pourrait detruire nos donnees lors du stop_module), si elle etait dans la lib-core on pourrait le faire lors du unload_texture, mais elle est dans le main.
+static gboolean cd_default_view_free_data (G_GNUC_UNUSED gpointer pUserData, CairoDock *pDock)  // si la vue 'default' etait dans un plug-in on n'aurait pas besoin de faire ca (on pourrait detruire nos donnees lors du stop_module), si elle etait dans la lib-core on pourrait le faire lors du unload_texture, mais elle est dans le main.
 {
 	if (pDock->bIsMainDock && s_iFlatSeparatorTexture != 0)
 	{
@@ -56,7 +53,7 @@ static gboolean cd_default_view_free_data (gpointer pUserData, CairoDock *pDock)
 		_cairo_dock_delete_texture (s_iFlatSeparatorTexture);
 		s_iFlatSeparatorTexture = 0;
 	}
-	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	return GLDI_NOTIFICATION_LET_PASS;
 }
 
 
@@ -68,17 +65,19 @@ static void cd_calculate_max_dock_size_default (CairoDock *pDock)
 
 	double fRadius = MIN (myDocksParam.iDockRadius, (pDock->iDecorationsHeight + myDocksParam.iDockLineWidth) / 2 - 1);
 	double fExtraWidth = myDocksParam.iDockLineWidth + 2 * (fRadius + myDocksParam.iFrameMargin);
-	pDock->iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->fFlatDockWidth, 1., fExtraWidth));
+	int iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->fFlatDockWidth, 1., fExtraWidth));
 	pDock->iOffsetForExtend = 0;
+	pDock->iMaxDockWidth = iMaxDockWidth;
 	
-	if (cairo_dock_is_extended_dock (pDock))  // mode panel etendu.
+	///if (cairo_dock_is_extended_dock (pDock))  // mode panel etendu.
+	if (pDock->iRefCount == 0)
 	{
 		if (pDock->iMaxDockWidth < cairo_dock_get_max_authorized_dock_width (pDock))  // alors on etend.
 		{
 			if (pDock->fAlign != .5)
 			{
-				pDock->iOffsetForExtend = (cairo_dock_get_max_authorized_dock_width (pDock) - pDock->iMaxDockWidth) / 2 - 0*fExtraWidth/2;
-				cd_debug ("iOffsetForExtend : %d; iMaxDockWidth : %d; fExtraWidth : %d\n", pDock->iOffsetForExtend, pDock->iMaxDockWidth, (int) fExtraWidth);
+				pDock->iOffsetForExtend = (cairo_dock_get_max_authorized_dock_width (pDock) - pDock->iMaxDockWidth) / 2;
+				cd_debug ("iOffsetForExtend : %d; iMaxDockWidth : %d; fExtraWidth : %d", pDock->iOffsetForExtend, pDock->iMaxDockWidth, (int) fExtraWidth);
 			}
 			fExtraWidth += (cairo_dock_get_max_authorized_dock_width (pDock) - pDock->iMaxDockWidth);
 			pDock->iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->fFlatDockWidth, 1., fExtraWidth));  // on pourra optimiser, ce qui nous interesse ici c'est les fXMin/fXMax.
@@ -107,6 +106,8 @@ static void cd_calculate_max_dock_size_default (CairoDock *pDock)
 	pDock->inputArea.width = pDock->fFlatDockWidth;
 	pDock->inputArea.height = pDock->iMinDockHeight;*/
 	
+	
+	
 	pDock->iMinLeftMargin = fExtraWidth/2;
 	pDock->iMinRightMargin = fExtraWidth/2;
 	Icon *pFirstIcon = cairo_dock_get_first_icon (pDock->icons);
@@ -117,22 +118,23 @@ static void cd_calculate_max_dock_size_default (CairoDock *pDock)
 		pDock->iMaxRightMargin = pDock->iMaxDockWidth - (pLastIcon->fXMin + pLastIcon->fWidth);
 	//g_print(" marges min: %d | %d\n marges max: %d | %d\n", pDock->iMinLeftMargin, pDock->iMinRightMargin, pDock->iMaxLeftMargin, pDock->iMaxRightMargin);
 	
-	if (pDock->fAlign != .5 & cairo_dock_is_extended_dock (pDock))
-		pDock->iMinDockWidth = pDock->iMaxDockWidth;
-	else
+	///if (pDock->fAlign != .5/** && cairo_dock_is_extended_dock (pDock)*/)
+	///	pDock->iMinDockWidth = pDock->iMaxDockWidth;
+	///else
 		pDock->iMinDockWidth = MAX (1, pDock->fFlatDockWidth);  // fFlatDockWidth peut etre meme negatif avec un dock vide.
 	
 	if (g_bUseOpenGL && s_iFlatSeparatorTexture == 0 && myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR)
 		s_iFlatSeparatorTexture = cairo_dock_create_texture_from_raw_data (blurTex, 32, 32);
 	
-	pDock->iActiveWidth = pDock->iMaxDockWidth;
+	///pDock->iActiveWidth = pDock->iMaxDockWidth;
+	pDock->iActiveWidth = iMaxDockWidth;
 	pDock->iActiveHeight = pDock->iMaxDockHeight;
 	if (! pDock->container.bIsHorizontal && myIconsParam.bTextAlwaysHorizontal)
 		pDock->iMaxDockHeight += 8*myIconsParam.iLabelSize;  // vertical dock, add some padding to draw the labels.	
 }
 
 
-static void _draw_flat_separator (Icon *icon, CairoDock *pDock, cairo_t *pCairoContext, double fDockMagnitude)
+static void _draw_flat_separator (Icon *icon, G_GNUC_UNUSED CairoDock *pDock, cairo_t *pCairoContext, G_GNUC_UNUSED double fDockMagnitude)
 {
 	double fSizeX = icon->fWidth * icon->fScale, fSizeY = icon->fHeight * icon->fScale;
 	cairo_set_operator (pCairoContext, CAIRO_OPERATOR_OVER);
@@ -160,9 +162,9 @@ static void _draw_flat_separator (Icon *icon, CairoDock *pDock, cairo_t *pCairoC
 	cairo_pattern_destroy (pPattern);
 }
 
-static void _draw_physical_separator (Icon *icon, CairoDock *pDock, cairo_t *pCairoContext, double fDockMagnitude)
+static void _draw_physical_separator (Icon *icon, CairoDock *pDock, cairo_t *pCairoContext, G_GNUC_UNUSED double fDockMagnitude)
 {
-	double fSizeX = icon->fWidth * icon->fScale, fSizeY = icon->fHeight * icon->fScale;
+	double fSizeX = icon->fWidth * icon->fScale;
 	cairo_set_line_width (pCairoContext, myDocksParam.iDockLineWidth);
 	cairo_set_operator (pCairoContext, CAIRO_OPERATOR_DEST_OUT);
 	cairo_set_source_rgba (pCairoContext, 0.0, 0.0, 0.0, 1.0);
@@ -243,6 +245,7 @@ static void cd_render_default (cairo_t *pCairoContext, CairoDock *pDock)
 			fDockOffsetX = fExtraWidth / 2;
 		if (fDockOffsetX + fDockWidth + fExtraWidth / 2 > pDock->container.iWidth)
 			fDockWidth = pDock->container.iWidth - fDockOffsetX - fExtraWidth / 2;
+		fDockOffsetX += (pDock->iOffsetForExtend * (pDock->fAlign - .5) * 2);
 	}
 	if (pDock->container.bDirectionUp)
 	{
@@ -292,7 +295,7 @@ static void cd_render_default (cairo_t *pCairoContext, CairoDock *pDock)
 		icon = ic->data;
 
 		cairo_save (pCairoContext);
-		if (myIconsParam.iSeparatorType != CAIRO_DOCK_NORMAL_SEPARATOR && icon->cFileName == NULL && CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon))
+		if (myIconsParam.iSeparatorType != CAIRO_DOCK_NORMAL_SEPARATOR && icon->cFileName == NULL && GLDI_OBJECT_IS_SEPARATOR_ICON (icon))
 			_cairo_dock_draw_separator (icon, pDock, pCairoContext, fDockMagnitude);
 		else
 			cairo_dock_render_one_icon (icon, pDock, pCairoContext, fDockMagnitude, TRUE);
@@ -309,7 +312,6 @@ static void cd_render_optimized_default (cairo_t *pCairoContext, CairoDock *pDoc
 	//g_print ("%s ((%d;%d) x (%d;%d) / (%dx%d))\n", __func__, pArea->x, pArea->y, pArea->width, pArea->height, pDock->container.iWidth, pDock->container.iHeight);
 	double fLineWidth = myDocksParam.iDockLineWidth;
 	double fMargin = myDocksParam.iFrameMargin;
-	int iWidth = pDock->container.iWidth;
 	int iHeight = pDock->container.iHeight;
 
 	//\____________________ On dessine les decorations du fond sur la portion de fenetre.
@@ -392,7 +394,6 @@ static void cd_render_optimized_default (cairo_t *pCairoContext, CairoDock *pDoc
 	{
 		double fXMin = (pDock->container.bIsHorizontal ? pArea->x : pArea->y), fXMax = (pDock->container.bIsHorizontal ? pArea->x + pArea->width : pArea->y + pArea->height);
 		double fDockMagnitude = cairo_dock_calculate_magnitude (pDock->iMagnitudeIndex);
-		double fRatio = pDock->container.fRatio;
 		double fXLeft, fXRight;
 		
 		//g_print ("redraw [%d -> %d]\n", (int) fXMin, (int) fXMax);
@@ -430,7 +431,7 @@ static void cd_render_optimized_default (cairo_t *pCairoContext, CairoDock *pDoc
 
 
 
-static void _draw_flat_separator_opengl (Icon *icon, CairoDock *pDock, double fDockMagnitude)
+static void _draw_flat_separator_opengl (Icon *icon, CairoDock *pDock, G_GNUC_UNUSED double fDockMagnitude)
 {
 	if (s_iFlatSeparatorTexture == 0)
 		return;
@@ -456,9 +457,9 @@ static void _draw_flat_separator_opengl (Icon *icon, CairoDock *pDock, double fD
 	_cairo_dock_disable_texture ();
 }
 
-static void _draw_physical_separator_opengl (Icon *icon, CairoDock *pDock, double fDockMagnitude)
+static void _draw_physical_separator_opengl (Icon *icon, CairoDock *pDock, G_GNUC_UNUSED double fDockMagnitude)
 {
-	double fSizeX = icon->fWidth * icon->fScale, fSizeY = icon->fHeight * icon->fScale;
+	double fSizeX = icon->fWidth * icon->fScale;
 	glEnable (GL_BLEND);
 	glBlendFunc (GL_ONE, GL_ZERO);
 	glColor4f (0., 0., 0., 0.);
@@ -559,6 +560,7 @@ static void cd_render_opengl_default (CairoDock *pDock)
 			fDockOffsetX = fLineWidth / 2;
 		if (fDockOffsetX + fDockWidth + (2*fRadius + fLineWidth) > pDock->container.iWidth)
 			fDockWidth = pDock->container.iWidth - fDockOffsetX - (2*fRadius + fLineWidth);
+		fDockOffsetX += (pDock->iOffsetForExtend * (pDock->fAlign - .5) * 2);
 	}
 	
 	fDockOffsetY = pDock->iDecorationsHeight + 1.5 * fLineWidth;
@@ -628,7 +630,7 @@ static void cd_render_opengl_default (CairoDock *pDock)
 		icon = ic->data;
 		
 		glPushMatrix ();
-		if (myIconsParam.iSeparatorType != CAIRO_DOCK_NORMAL_SEPARATOR && icon->cFileName == NULL && CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon))
+		if (myIconsParam.iSeparatorType != CAIRO_DOCK_NORMAL_SEPARATOR && icon->cFileName == NULL && GLDI_OBJECT_IS_SEPARATOR_ICON (icon))
 			_cairo_dock_draw_separator_opengl (icon, pDock, fDockMagnitude);
 		else
 			cairo_dock_render_one_icon_opengl (icon, pDock, fDockMagnitude, TRUE);
@@ -688,8 +690,8 @@ void cairo_dock_register_default_renderer (void)
 	cairo_dock_register_renderer (CAIRO_DOCK_DEFAULT_RENDERER_NAME, pDefaultRenderer);
 	
 	// when and only when the current theme is unloaded, the main dock is destroyed, and we must release our data.
-	cairo_dock_register_notification_on_object (&myDocksMgr,
+	gldi_object_register_notification (&myDockObjectMgr,
 		NOTIFICATION_DESTROY,  // on ne fait cette fonction qu'une fois, donc on peut s'enregistrer ici.
-		(CairoDockNotificationFunc) cd_default_view_free_data,
-		CAIRO_DOCK_RUN_AFTER, NULL);
+		(GldiNotificationFunc) cd_default_view_free_data,
+		GLDI_RUN_AFTER, NULL);
 }
